@@ -1,21 +1,31 @@
-#' @title Get location of airports and ports from GISCO API
-#' @name gisco_get_airports
-#' @description Loads a simple feature (\code{sf}) object from GISCO API
-#' entry point or your local library.
-#' @return A \code{POINT} object on EPSG:4326.
+#' Get location of airports and ports from GISCO API
+#'
+#' Loads a simple feature (`sf`) object from GISCO API or your local library.
+#'
+#' @concept infrastructure
+#'
+#' @return A `POINT` object on EPSG:4326.
+#'
 #' @param year Year of reference.
-#' @param country A list of countries, see \link{gisco_get_countries}
-#' @source \href{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/transport-networks}{GISCO API}
-#' @author dieghernan, \url{https://github.com/dieghernan/}
-#' @details \code{year} available:
-#' \itemize{
-#'    \item \code{gisco_get_airports} (\code{2006,2013})
-#'    \item \code{gisco_get_ports} (\code{2009,2013})
-#'    }
+#'
+#' @param country A list of countries, see [gisco_get_countries()]
+#'
+#' @source
+#' <https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/transport-networks>
+#'
+#' @author dieghernan, <https://github.com/dieghernan/>
+#'
+#' @details
+#' # Years available
+#'
+#' * **`gisco_get_airports`**:  "2006" and "2013"
+#' * **`gisco_get_ports`**: "2009" and "2013"
 #'
 #'  Ports 2009 contains worldwide information, the rest of datasets refer
 #'  to Europe. All shapefiles provided in EPSG:4326
+#'
 #' @examples
+#'
 #' library(sf)
 #'
 #' NL <- gisco_get_countries(country = "NL")
@@ -68,19 +78,20 @@ gisco_get_airports <- function(year = "2013", country = NULL) {
   }
 
   if (year == "2013") {
-    data.sf <- airports2013
+    data_sf <- airports2013
   } else if (year == "2006") {
-    data.sf <- airports2006
+    data_sf <- airports2006
   }
 
-  if (!is.null(country) & "CNTR_CODE" %in% names(data.sf)) {
+  if (!is.null(country) & "CNTR_CODE" %in% names(data_sf)) {
     country <- gsc_helper_countrynames(country, "eurostat")
-    data.sf <- data.sf[data.sf$CNTR_CODE %in% country, ]
+    data_sf <- data_sf[data_sf$CNTR_CODE %in% country, ]
   }
-  return(data.sf)
+  return(data_sf)
 }
 
 #' @rdname gisco_get_airports
+#'
 #' @export
 gisco_get_ports <- function(year = "2013") {
   year <- as.character(year)
@@ -89,9 +100,9 @@ gisco_get_ports <- function(year = "2013") {
   }
 
   if (year == "2013") {
-    data.sf <- ports2013
+    data_sf <- ports2013
   } else if (year == "2009") {
-    data.sf <- ports2009
+    data_sf <- ports2009
   }
-  return(data.sf)
+  return(data_sf)
 }
