@@ -1,30 +1,47 @@
-#' @title Get the grid cells covering the European
-#' land territory, for various resolutions.
-#' @description These datasets contain grid cells covering the European land
+#' Get the grid cells covering the European land territory
+#'
+#' @description
+#' These datasets contain grid cells covering the European land
 #' territory, for various resolutions from 1km to 100km. Base statistics such
 #' as population figures are provided for these cells.
-#' @return A \code{POLYGON/POINT} object.
-#' @author dieghernan, \url{https://github.com/dieghernan/}
-#' @source \href{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/grids}{GISCO API Grids}
-#' @param resolution Resolution of the grid cells on kms. Available values are
-#' \code{1, 2, 5, 10, 20, 50, 100}. See Details
-#' @param spatialtype Select one of \code{REGION,POINT}
-#' @param cache_dir,update_cache,verbose See \link{gisco_get}
-#' @details Files are distributed on EPSG:3035.
 #'
-#'   The file sizes range is from 428K (\code{resolution = "100"})
-#' to 1.7G \code{resolution = "1"}. For resolutions 1km and 2km you would
+#' @concept misc
+#'
+#' @return A `POLYGON/POINT` object.
+#'
+#' @author dieghernan, <https://github.com/dieghernan/>
+#'
+#' @source
+#' <https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/grids>
+#'
+#' @param resolution Resolution of the grid cells on kms. Available values are
+#' "1", "2", "5", "10", "20", "50", "100". See Details
+#'
+#' @param spatialtype Select one of `REGION,POINT`
+#'
+#' @inheritParams gisco_get
+#'
+#' @details
+#'
+#' Files are distributed on EPSG:3035.
+#'
+#' The file sizes range is from 428Kb (`resolution = "100"`)
+#' to 1.7Gb `resolution = "1"`. For resolutions 1km and 2km you would
 #' need to confirm the download.
-#' @note There are specific downloading provisions, please see
-#' \url{https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/grids}
+#'
+#' @note
+#' There are specific downloading provisions, please see
+#' <https://ec.europa.eu/eurostat/web/gisco/geodata/reference-data/grids>
+#'
 #' @examples
 #' library(sf)
 #'
 #' grid <- gisco_get_grid(resolution = 20)
-#' grid$popdens <- grid$TOT_P_2011/20
+#' grid$popdens <- grid$TOT_P_2011 / 20
 #'
 #' breaks <-
-#'   c(0,
+#'   c(
+#'     0,
 #'     500,
 #'     1000,
 #'     2500,
@@ -32,13 +49,14 @@
 #'     10000,
 #'     25000,
 #'     50000,
-#'     max(grid$popdens) + 1)
+#'     max(grid$popdens) + 1
+#'   )
 #'
-#' pal <- hcl.colors(length(breaks)-2, palette = "inferno", alpha = 0.7)
-#' pal <- c("black",pal)
+#' pal <- hcl.colors(length(breaks) - 2, palette = "inferno", alpha = 0.7)
+#' pal <- c("black", pal)
 #'
 #' opar <- par(no.readonly = TRUE)
-#' par(mar=c(0,0,0,0), bg = "grey2")
+#' par(mar = c(0, 0, 0, 0), bg = "grey2")
 #' plot(
 #'   grid[, "popdens"],
 #'   pal = pal,
@@ -46,7 +64,7 @@
 #'   breaks = breaks,
 #'   main = NA,
 #'   xlim = c(2500000, 7000000),
-#'   ylim = c(1500000 , 5200000),
+#'   ylim = c(1500000, 5200000),
 #'   border = NA
 #' )
 #' par(opar)
@@ -60,8 +78,10 @@ gisco_get_grid <- function(resolution = "20",
   validres <- as.character(c(1, 2, 5, 10, 20, 50, 100))
 
   if (!resolution %in% validres) {
-    stop("resolution should be one of ",
-         paste0(validres, collapse = ", "))
+    stop(
+      "resolution should be one of ",
+      paste0(validres, collapse = ", ")
+    )
   }
 
   valid <- c("REGION", "POINT")
@@ -73,7 +93,7 @@ gisco_get_grid <- function(resolution = "20",
   if (isFALSE(update_cache)) {
     if (resolution == "20" & spatialtype == "REGION") {
       dwnload <- FALSE
-      data.sf <- grid20km
+      data_sf <- grid20km
     }
   }
   if (dwnload) {
@@ -86,17 +106,20 @@ gisco_get_grid <- function(resolution = "20",
     local <- file.path(gsc_helper_cachedir(cache_dir), filename)
     exist_local <- file.exists(local)
 
-    if (verbose & exist_local)
+    if (verbose & exist_local) {
       message("File exits on local cache dir")
-
+    }
+    # nocov start
     if (resolution %in% c("1", "2") & isFALSE(exist_local)) {
       sel <-
         menu(c("Yes", "No"),
-             title = "You are about to download a large file (>500M). Proceed?")
+          title = "You are about to download a large file (>500M). Proceed?"
+        )
       if (sel != 1) {
         stop("Execution halted")
       }
     }
+    # nocov end
 
 
     localfile <-
@@ -120,6 +143,7 @@ gisco_get_grid <- function(resolution = "20",
         return(NULL)
       }
     )
+    # nocov start
     if (is.null(load)) {
       stop(
         "\n Malformed ",
@@ -129,8 +153,9 @@ gisco_get_grid <- function(resolution = "20",
         "\n to your cache_dir folder"
       )
     } else {
-      data.sf <- load
+      data_sf <- load
     }
+    # nocov end
   }
-  return(data.sf)
+  return(data_sf)
 }
