@@ -1,61 +1,83 @@
-#' @title Get geospatial units data from GISCO API
-#' @description Download individual shapefiles of units. Unlike
-#' \link{gisco_get_countries}, \link{gisco_get_nuts} or
-#' \link{gisco_get_urban_audit}, that downloads a full dataset
-#' and applies filters, \code{gisco_get_units} downloads a single shapefiles
-#' for each unit.
-#' @return A \code{sf} object on \code{mode = "sf"} or a dataframe on
-#' \code{mode = "df"}.
-#' @param id_giscoR Select the \code{unit} type to be downloaded.
-#' Accepted values are \code{'nuts','countries'} or \code{'urban_audit'}.
+#' Get geospatial units data from GISCO API
+#'
+#' @description
+#' Download individual shapefiles of units. Unlike [gisco_get_countries()],
+#' [gisco_get_nuts()] or [gisco_get_urban_audit()], that downloads a full
+#' dataset and applies filters, [gisco_get_units()] downloads a single
+#' shapefile for each unit.
+#'
+#' @concept political
+#'
+#' @return
+#' A `sf` object on `mode = "sf"` or a dataframe on `mode = "df"`.
+#'
+#' @param id_giscoR Select the `unit` type to be downloaded.
+#' Accepted values are "nuts", "countries" or "urban_audit".
+#'
 #' @param unit Unit ID to be downloaded. See Details.
-#' @param mode Controls the output of the function. Possible values
-#' are \code{"sf"} or \code{"df"}. See Value and Details.
-#' @param year,epsg,cache,update_cache,cache_dir,verbose,resolution See
-#'  \link{gisco_get}.
-#' @param spatialtype Type of geometry to be returned: \code{"RG"}
-#' for \code{POLYGON} and \code{"LB"} for \code{POINT}.
-#' @details The function can return a dataframe on \code{mode = "df"}
-#' or a \code{sf} object on \code{mode = "sf"}
 #'
-#' In order to see the available \code{unit} ids with the required
-#' combination of \code{what,year}, first run the function on \code{"df"}
+#' @param mode Controls the output of the function. Possible values are "sf"
+#' or "df". See Value and Details.
+#'
+#' @param spatialtype Type of geometry to be returned: "RG", for `POLYGON` and
+#' "LB" for `POINT`.
+#'
+#' @inheritParams gisco_get
+#'
+#' @details
+#' The function can return a dataframe on `mode = "df"` or a `sf` object
+#' on `mode = "sf"`.
+#'
+#' In order to see the available `unit` ids with the required
+#' combination of `spatialtype, year`, first run the function on "df"
 #' mode. Once that you get the data frame you can select the required ids
-#' on the \code{unit} parameter.
+#' on the `unit` parameter.
+#'
+#' On `mode = "df"` the only relevant parameters are `spatialtype, year`.
+#'
+#' @note
+#' Country-level files would be renamed on your `cache_dir`
+#' to avoid naming conflicts with NUTS-0 datasets.
+#'
+#' @author dieghernan, <https://github.com/dieghernan/>
+#' @source <https://gisco-services.ec.europa.eu/distribution/v2/>
+#'
+#' @seealso [gisco_get]
 #'
-#' On \code{mode = "df"} the only relevant parameters are \code{what, year}.
-#' @note \code{countries} file would be renamed on your \code{cache_dir}
-#' to avoid naming conflicts with \code{nuts} datasets.
-#' @author dieghernan, \url{https://github.com/dieghernan/}
-#' @source \href{https://gisco-services.ec.europa.eu/distribution/v2/}{
-#' GISCO API}
-#' @seealso \link{gisco_get}
 #' @examples
 #' \dontrun{
 #' library(sf)
 #'
 #' if (gisco_check_access()) {
-#'   cities <- gisco_get_units(id_giscoR = "urban_audit",
-#'                             mode = "df",
-#'                             year = "2020")
-#'   VAL <- cities[grep("Valencia", cities$URAU_NAME),]
-#'   # Order from big to small
-#'   VAL <- VAL[order(as.double(VAL$AREA_SQM), decreasing =  TRUE), ]
+#'   cities <- gisco_get_units(
+#'     id_giscoR = "urban_audit",
+#'     mode = "df",
+#'     year = "2020"
+#'   )
+#'   VAL <- cities[grep("Valencia", cities$URAU_NAME), ]
+#'   #'   Order from big to small
+#'   VAL <- VAL[order(as.double(VAL$AREA_SQM), decreasing = TRUE), ]
 #'
-#'   VAL.sf <- gisco_get_units(id_giscoR = "urban_audit",
-#'                             year = "2020",
-#'                             unit = VAL$URAU_CODE)
+#'   VAL.sf <- gisco_get_units(
+#'     id_giscoR = "urban_audit",
+#'     year = "2020",
+#'     unit = VAL$URAU_CODE
+#'   )
 #'   # Provincia
 #'   Provincia <-
-#'     gisco_get_units(id_giscoR = "nuts",
-#'                     unit = c("ES523"),
-#'                     resolution = "01")
+#'     gisco_get_units(
+#'       id_giscoR = "nuts",
+#'       unit = c("ES523"),
+#'       resolution = "01"
+#'     )
 #'
 #'   # Surrounding area
 #'   NUTS1 <-
-#'     gisco_get_units(id_giscoR = "nuts",
-#'                     unit = c("ES5"),
-#'                     resolution = "01")
+#'     gisco_get_units(
+#'       id_giscoR = "nuts",
+#'       unit = c("ES5"),
+#'       resolution = "01"
+#'     )
 #'
 #'   # Plot
 #'   plot(
@@ -65,9 +87,10 @@
 #'     lwd = 3
 #'   )
 #'   plot(st_geometry(NUTS1),
-#'        border = "grey50",
-#'        lwd = 3,
-#'        add = TRUE)
+#'     border = "grey50",
+#'     lwd = 3,
+#'     add = TRUE
+#'   )
 #'   plot(
 #'     st_geometry(VAL.sf),
 #'     col = c("deeppink4", "brown2", "khaki1"),
@@ -83,17 +106,17 @@
 #' }
 #' }
 #' @export
-gisco_get_units <-  function(id_giscoR = "nuts",
-                             unit = "ES4",
-                             mode = "sf",
-                             year = "2016",
-                             epsg = "4326",
-                             cache = TRUE,
-                             update_cache = FALSE,
-                             cache_dir = NULL,
-                             verbose = FALSE,
-                             resolution = "20",
-                             spatialtype = "RG") {
+gisco_get_units <- function(id_giscoR = "nuts",
+                            unit = "ES4",
+                            mode = "sf",
+                            year = "2016",
+                            epsg = "4326",
+                            cache = TRUE,
+                            update_cache = FALSE,
+                            cache_dir = NULL,
+                            verbose = FALSE,
+                            resolution = "20",
+                            spatialtype = "RG") {
   year <- as.character(year)
 
   if (!(id_giscoR %in% c("countries", "nuts", "urban_audit"))) {
@@ -112,7 +135,7 @@ gisco_get_units <-  function(id_giscoR = "nuts",
     stop("Select unit(s) to download with unit = c('unit_id1','unit_id2')")
   }
 
-  #Convert to iso3c for countries 2001
+  # Convert to iso3c for countries 2001
   if (mode == "sf" & id_giscoR == "countries") {
     if (year == "2001") {
       unit <- gsc_helper_countrynames(unit, "iso3c")
@@ -140,8 +163,8 @@ gisco_get_units <-  function(id_giscoR = "nuts",
       verbose = verbose,
       level = level
     )
-  api_entry <- unlist(strsplit(routes$api.url, "/geojson/"))[1]
-  remain <- unlist(strsplit(routes$api.url, "/geojson/"))[2]
+  api_entry <- unlist(strsplit(routes$api_url, "/geojson/"))[1]
+  remain <- unlist(strsplit(routes$api_url, "/geojson/"))[2]
 
 
 
@@ -179,7 +202,7 @@ gisco_get_units <-  function(id_giscoR = "nuts",
       }
     )
     if (!isTRUE(ondwn)) {
-      df.csv <- read.csv2(
+      df_csv <- read.csv2(
         tempf,
         sep = ",",
         stringsAsFactors = FALSE,
@@ -188,9 +211,9 @@ gisco_get_units <-  function(id_giscoR = "nuts",
       if (verbose) {
         message("Load database succesfully")
       }
-      return(df.csv)
+      return(df_csv)
     }
-  }  else {
+  } else {
     unit <- unique(unit)
     filename <- unit
 
@@ -199,7 +222,7 @@ gisco_get_units <-  function(id_giscoR = "nuts",
     # Slice path
     remain <- gsub(paste0("_", level), "", remain)
     filepattern <- tolower(gsub(".geojson", "", remain))
-    slice <- (unlist(strsplit(filepattern, "_")))[c(-1,-2)]
+    slice <- (unlist(strsplit(filepattern, "_")))[c(-1, -2)]
 
     # Remove year epsg and spatial type
     slice <- slice[-grep(year, slice)]
@@ -214,13 +237,12 @@ gisco_get_units <-  function(id_giscoR = "nuts",
         paste0(paste("-region", slice, epsg, year, sep = "-"), ".geojson")
       filepattern <- gsub("-rg", "", filepattern)
       filename <- paste0(filename, filepattern)
-
     }
 
     for (i in seq_len(length(filename))) {
       fn <- filename[i]
       if (id_giscoR == "countries") {
-        #Modify name for countries
+        # Modify name for countries
         fn <- gsub(unit[i], paste0(unit[i], "-cntry"), fn)
       }
 
@@ -242,32 +264,31 @@ gisco_get_units <-  function(id_giscoR = "nuts",
         next()
       }
 
-      iter.sf <- tryCatch(
-        gsc_api_load(path, epsg, "geojson", cache, verbose)
-        ,
+      iter_sf <- tryCatch(
+        gsc_api_load(path, epsg, "geojson", cache, verbose),
         error = function(e) {
           return(NULL)
         }
       )
-      if (is.null(iter.sf)) {
+      if (is.null(iter_sf)) {
         message("\n Skipping unit = ", unit[i], "\n Corrupted file")
         next()
       }
 
 
-      if (exists("df.sf")) {
-        df.sf <- rbind(df.sf, iter.sf)
+      if (exists("df_sf")) {
+        df_sf <- rbind(df_sf, iter_sf)
       } else {
-        df.sf <- iter.sf
+        df_sf <- iter_sf
       }
     }
 
-    if (!exists("df.sf")) {
+    if (!exists("df_sf")) {
       stop("No results for ", paste0(unit, collapse = " "))
     }
 
     # Last check
-    df.sf <- sf::st_make_valid(df.sf)
-    return(df.sf)
+    df_sf <- sf::st_make_valid(df_sf)
+    return(df_sf)
   }
 }
