@@ -1,13 +1,24 @@
-#' @title Check access to GISCO API
-#' @description Check if R has access to resources
-#' at \url{https://gisco-services.ec.europa.eu/distribution/v2/}.
+#' Check access to GISCO API
+#'
+#' @concept helper
+#'
+#' @description
+#' Check if R has access to resources at
+#' <https://gisco-services.ec.europa.eu/distribution/v2/>.
+#'
 #' @return a logical.
+#'
 #' @examples
+#'
 #' gisco_check_access()
 #' @export
 gisco_check_access <- function() {
-  url <-
-    "https://gisco-services.ec.europa.eu/distribution/v2/nuts/geojson/NUTS_LB_2016_4326_LEVL_0.geojson"
+  url <- paste0(
+    "https://gisco-services.ec.europa.eu/",
+    "distribution/v2/nuts/geojson/",
+    "NUTS_LB_2016_4326_LEVL_0.geojson"
+  )
+  # nocov start
   access <-
     tryCatch(
       download.file(url, destfile = tempfile(), quiet = TRUE),
@@ -15,7 +26,7 @@ gisco_check_access <- function() {
         return(FALSE)
       }
     )
-  # nocov start
+
   if (isFALSE(access)) {
     return(FALSE)
   } else {
@@ -25,7 +36,7 @@ gisco_check_access <- function() {
 }
 
 
-#' @name gsc_helper_cachedir
+#' gsc_helper_cachedir
 #' @noRd
 gsc_helper_cachedir <- function(cache_dir = NULL) {
   # Check cache dir from options if not set
@@ -36,10 +47,9 @@ gsc_helper_cachedir <- function(cache_dir = NULL) {
   if (is.null(cache_dir)) {
     cache_dir <- file.path(tempdir(), "gisco")
   }
-
-  #Create cache dir if needed
+  # Create cache dir if needed
   if (isFALSE(dir.exists(cache_dir))) {
-    dir.create(cache_dir)
+    dir.create(cache_dir, recursive = TRUE)
   }
   return(cache_dir)
 }
@@ -64,125 +74,146 @@ gsc_api_url <- function(id_giscoR = "nuts",
   db <- db[db$id_giscoR == id_giscoR, ]
 
   # Available years
-  av.years <- paste(db$year, collapse = ",")
-  av.years  <- sort(unique(unlist(strsplit(av.years , ","))))
+  av_years <- paste(db$year, collapse = ",")
+  av_years <- sort(unique(unlist(strsplit(av_years, ","))))
 
-  if (!(year %in% av.years))
-    stop("Year ",
-         year,
-         " not available. Try ",
-         paste0("'", av.years, "'", collapse = ","))
+  if (!(year %in% av_years)) {
+    stop(
+      "Year ",
+      year,
+      " not available. Try ",
+      paste0("'", av_years, "'", collapse = ",")
+    )
+  }
 
-  db <- db[grep(year, db$year),]
+  db <- db[grep(year, db$year), ]
 
 
-  rm(av.years)
+  rm(av_years)
 
   # Available epsg
-  av.epsg <- paste(db$epsg, collapse = ",")
-  av.epsg  <- sort(unique(unlist(strsplit(av.epsg , ","))))
+  av_epsg <- paste(db$epsg, collapse = ",")
+  av_epsg <- sort(unique(unlist(strsplit(av_epsg, ","))))
 
 
-  if (!(epsg %in% av.epsg))
-    stop("EPSG ",
-         epsg,
-         " not available. Try ",
-         paste0("'", av.epsg, "'", collapse = ","))
+  if (!(epsg %in% av_epsg)) {
+    stop(
+      "EPSG ",
+      epsg,
+      " not available. Try ",
+      paste0("'", av_epsg, "'", collapse = ",")
+    )
+  }
 
 
-  db <- db[grep(epsg, db$epsg),]
-  rm(av.epsg)
+  db <- db[grep(epsg, db$epsg), ]
+  rm(av_epsg)
 
   # Available ext
   # nocov start
-  av.ext <- paste(db$ext, collapse = ",")
-  av.ext  <- sort(unique(unlist(strsplit(av.ext , ","))))
+  av_ext <- paste(db$ext, collapse = ",")
+  av_ext <- sort(unique(unlist(strsplit(av_ext, ","))))
+
+
+
+  if (!(ext %in% av_ext)) {
+    stop(
+      "\n",
+      ext,
+      " format not available. Try one of ",
+      paste0("'", av_ext, "'", collapse = ",")
+    )
+  }
   # nocov end
 
-
-  if (!(ext %in% av.ext))
-    stop("\n",
-         ext,
-         " format not available. Try one of ",
-         paste0("'", av.ext, "'", collapse = ","))
-
-
-  db <- db[grep(ext, db$ext),]
-  rm(av.ext)
+  db <- db[grep(ext, db$ext), ]
+  rm(av_ext)
 
 
   # Available spatialtype
-  av.sptype <- paste(db$spatialtype, collapse = ",")
-  av.sptype  <- sort(unique(unlist(strsplit(av.sptype , ","))))
+  av_sptype <- paste(db$spatialtype, collapse = ",")
+  av_sptype <- sort(unique(unlist(strsplit(av_sptype, ","))))
 
-  if (length(av.sptype) == 1) {
-    if (verbose)
-      message("[Auto] Selecting spatialtype = '", av.sptype, "'\n")
-    spatialtype <- av.sptype
+  if (length(av_sptype) == 1) {
+    if (verbose) {
+      message("[Auto] Selecting spatialtype = '", av_sptype, "'\n")
+    }
+    spatialtype <- av_sptype
   } else {
-    if (!(spatialtype %in% av.sptype))
+    if (!(spatialtype %in% av_sptype)) {
       stop(
         "spatialtype '",
         spatialtype,
         "' not available. Try ",
-        paste0("'", av.sptype, "'", collapse = ","),
+        paste0("'", av_sptype, "'", collapse = ","),
         "\n"
       )
+    }
     db <- db[grep(spatialtype, db$spatialtype), ]
   }
 
-  rm(av.sptype)
+  rm(av_sptype)
 
   # Available resolution
-  av.res <- paste(db$resolution, collapse = ",")
-  av.res  <- sort(unique(unlist(strsplit(av.res , ","))))
+  av_res <- paste(db$resolution, collapse = ",")
+  av_res <- sort(unique(unlist(strsplit(av_res, ","))))
 
-  if (length(av.res) == 1) {
-    if (verbose)
-      message("[Auto] Selecting resolution = '", av.res, "'\n")
-    resolution <- av.res
+  if (length(av_res) == 1) {
+    if (verbose) {
+      message("[Auto] Selecting resolution = '", av_res, "'\n")
+    }
+    resolution <- av_res
   } else {
-    if (!(resolution %in% av.res))
+    if (!(resolution %in% av_res)) {
       stop(
         "resolution '",
         resolution,
         "' not available for year ",
         year,
         ". Try ",
-        paste0("'", av.res, "'", collapse = ","),
+        paste0("'", av_res, "'", collapse = ","),
         "\n"
       )
+    }
     db <- db[grep(resolution, db$resolution), ]
   }
-  rm(av.res)
+  rm(av_res)
 
   # NUTS LEVEL
   if (id_giscoR == "nuts") {
-    av.nuts <- paste(db$nuts_level, collapse = ",")
-    av.nuts  <- sort(unique(unlist(strsplit(av.nuts, ","))))
+    av_nuts <- paste(db$nuts_level, collapse = ",")
+    av_nuts <- sort(unique(unlist(strsplit(av_nuts, ","))))
 
-    if (is.null((nuts_level)))
+    if (is.null((nuts_level))) {
       nuts_level <- "error"
+    }
 
 
-    if (!(nuts_level %in% av.nuts))
-      stop("Select one nuts level of ",
-           paste0("'", av.nuts, "'", collapse = ","))
+    if (!(nuts_level %in% av_nuts)) {
+      stop(
+        "Select one nuts level of ",
+        paste0("'", av_nuts, "'", collapse = ",")
+      )
+    }
     db <- db[grep(nuts_level, db$nuts_level), ]
   }
 
   # Urban Audit Level
   if (id_giscoR == "urban_audit") {
-    av.ualevel <- paste(db$level, collapse = ",")
-    av.ualevel  <- sort(unique(unlist(strsplit(av.ualevel, ","))))
+    av_ualevel <- paste(db$level, collapse = ",")
+    av_ualevel <- sort(unique(unlist(strsplit(av_ualevel, ","))))
 
-    if (is.null((level)))
+    if (is.null((level))) {
       level <- "all"
+    }
 
 
-    if (!(level %in% av.ualevel))
-      stop("Select one level of ",
-           paste0("'", av.ualevel, "'", collapse = ","))
+    if (!(level %in% av_ualevel)) {
+      stop(
+        "Select one level of ",
+        paste0("'", av_ualevel, "'", collapse = ",")
+      )
+    }
     db <- db[grep(level, db$level), ]
   }
 
@@ -196,49 +227,54 @@ gsc_api_url <- function(id_giscoR = "nuts",
       paste0(rownames(db), collapse = ","),
       " matches your selection. ",
       "Selecting row ",
-      rownames(db[1,])
+      rownames(db[1, ])
     )
     message("\n Consider opening an issue.")
-    db <- db[1,]
+    db <- db[1, ]
   }
   # nocov end
 
 
-  gisco.path <- db$api_file
+  gisco_path <- db$api_file
   # Create api call
   params <-
-    c("year",
+    c(
+      "year",
       "epsg",
       "resolution",
       "spatialtype",
       "nuts_level",
       "level",
-      "ext")
+      "ext"
+    )
 
 
   for (i in seq_len(length(params))) {
     patt <- paste0("\\{", params[i], "\\}")
     repl <- eval(parse(text = params[i]))
-    if (is.null(repl))
+    if (is.null(repl)) {
       repl <- "ERR"
-    gisco.path <- gsub(patt, repl, x = gisco.path)
+    }
+    gisco_path <- gsub(patt, repl, x = gisco_path)
   }
 
   # TopoJson has .json extension
   if (ext == "topojson") {
-    gisco.path <-
-      gsub(paste0(".", ext), ".json", gisco.path, fixed = TRUE)
+    gisco_path <-
+      gsub(paste0(".", ext), ".json", gisco_path, fixed = TRUE)
   }
 
   # Shp are zips
   if (ext %in% c("shp", "svg")) {
-    gisco.path <- paste0(gisco.path, ".zip")
+    gisco_path <- paste0(gisco_path, ".zip")
   }
-  namefile <- gsub(paste0(ext, "/"), "", gisco.path)
-  api.url <- file.path(db$api_entry, gisco.path)
+  namefile <- gsub(paste0(ext, "/"), "", gisco_path)
+  api_url <- file.path(db$api_entry, gisco_path)
 
-  output <- list(api.url = api.url,
-                 namefile = namefile)
+  output <- list(
+    api_url = api_url,
+    namefile = namefile
+  )
 
   return(output)
 }
@@ -257,22 +293,28 @@ gsc_api_cache <-
     file.local <- file.path(cache_dir, name)
     file.local <- gsub("//", "/", file.local)
 
-    if (verbose)
+    if (verbose) {
       message("\nCache dir is ", cache_dir, "\n")
+    }
 
     # Check if file already exists
     fileoncache <- file.exists(file.local)
 
     if (isFALSE(update_cache) & fileoncache) {
-      if (verbose)
-        message("\nFile already cached\n",
-                file.local)
+      if (verbose) {
+        message(
+          "\nFile already cached\n",
+          file.local
+        )
+      }
     } else {
-      if (fileoncache & verbose)
+      if (fileoncache & verbose) {
         message("\nUpdating cached file\n")
+      }
 
-      if (verbose)
+      if (verbose) {
         message("Downloading from ", url, "\n")
+      }
       err_dwnload <- tryCatch(
         download.file(
           url,
@@ -317,19 +359,23 @@ gsc_api_load <- function(file = NULL,
       size <- file.size(file)
       class(size) <- "object_size"
       message(format(size, units = "auto"))
-    } else{
-      if (verbose)
+    } else {
+      if (verbose) {
         message("Reading from url ", file)
+      }
     }
     if (ext == "geojson") {
       err_onload <- tryCatch(
-        data.sf <- geojsonsf::geojson_sf(file,
-                                         input = num$input,
-                                         wkt = num$wkt),
+        data_sf <- geojsonsf::geojson_sf(file,
+          input = num$input,
+          wkt = num$wkt
+        ),
         warning = function(e) {
-          message("\n\nFile couldn't be loaded from \n\n",
-                  file,
-                  "\n\n Please try cache = TRUE")
+          message(
+            "\n\nFile couldn't be loaded from \n\n",
+            file,
+            "\n\n Please try cache = TRUE"
+          )
           return(TRUE)
         },
         error = function(e) {
@@ -344,16 +390,18 @@ gsc_api_load <- function(file = NULL,
     } else {
       # nocov start
       err_onload <- tryCatch(
-        data.sf <-
+        data_sf <-
           sf::st_read(
             file,
             stringsAsFactors = FALSE,
             quiet = !verbose
           ),
         warning = function(e) {
-          message("\n\nFile couldn't be loaded from \n\n",
-                  file,
-                  "\n\n Please try cache = TRUE")
+          message(
+            "\n\nFile couldn't be loaded from \n\n",
+            file,
+            "\n\n Please try cache = TRUE"
+          )
           return(TRUE)
         },
         error = function(e) {
@@ -372,17 +420,19 @@ gsc_api_load <- function(file = NULL,
       loaded <- FALSE
     } else {
       loaded <- TRUE
-      if (verbose)
+      if (verbose) {
         message("File loaded")
+      }
     }
 
     if (loaded) {
-      if (verbose)
+      if (verbose) {
         message("Encoding characters")
+      }
       # To UTF-8
-      data.sf <- gsc_helper_utf8(data.sf)
-      data.sf <- sf::st_make_valid(data.sf)
-      return(data.sf)
+      data_sf <- gsc_helper_utf8(data_sf)
+      data_sf <- sf::st_make_valid(data_sf)
+      return(data_sf)
     } else {
       stop("\nExecution halted")
     }
@@ -426,12 +476,13 @@ gsc_unzip <-
 
 
 
-    #Extract files
+    # Extract files
     if (continue) {
       outfiles <- infiles[grep(ext, infiles$Name), ]$Name
 
-      if (verbose)
+      if (verbose) {
         message("Extracting files: ", paste0(outfiles, collapse = "\n"), "\n")
+      }
       tryCatch(
         unzip(
           destfile,
@@ -467,16 +518,20 @@ gsc_unzip <-
       rec <- (length(loopzip) > 0)
     }
     if (rec) {
-      if (verbose)
-        message("Extracting recursively files ",
-                paste0(loopzip, collapse = "\n"),
-                "\n")
+      if (verbose) {
+        message(
+          "Extracting recursively files ",
+          paste0(loopzip, collapse = "\n"),
+          "\n"
+        )
+      }
       for (i in seq_len(length(loopzip))) {
         fpath <- file.path(cache_dir, loopzip[i])
         tryCatch(
           unzip(fpath,
-                exdir = cache_dir,
-                overwrite = update_cache),
+            exdir = cache_dir,
+            overwrite = update_cache
+          ),
           warning = function(e) {
             message(
               "\nSome files of ",
