@@ -1,6 +1,3 @@
-library(tinytest)
-
-
 expect_error(gisco_get_countries(year = 2001, resolution = 60))
 expect_error(gisco_get_countries(year = 2011))
 expect_error(gisco_get_countries(epsg = 2819))
@@ -15,6 +12,7 @@ expect_silent(gisco_get_countries(country = "ES"))
 expect_true(nrow(gisco_get_countries(country = "Spain")) == 1)
 expect_true(nrow(gisco_get_countries(country = "ES")) == 1)
 expect_silent(gisco_get_countries(region = c("Africa", "Americas")))
+expect_true(nrow(gisco_get_countries(region = c("EU"))) == 27)
 expect_true(nrow(gisco_get_countries(country = c("Spain", "Italia"))) == 2)
 expect_true(nrow(gisco_get_countries(country = c("ES", "IT"))) == 2)
 expect_true(nrow(gisco_get_countries(country = c("ESP", "ITA"))) == 2)
